Idaho Supreme Court Criminal Opinions | Supreme Court

Skip to main content

# STATE OF IDAHO JUDICIAL BRANCH
Supreme Court Appeals

## Search form

Search

## Idaho Supreme Court Criminal Opinions

The Idaho Supreme Court and Idaho Court of Appeals cited opinions are made available online as a public service. All cited opinions are posted the day of their release. West Publishing Company publishes all cited opinions in the Pacific Reporter and Idaho Reports volumes. All cited opinions are removed from this site one-year upon release.

NOTICE: These opinions are subject to formal revision before publication in the preliminary print of the Pacific Reporter. Readers are requested to notify the Clerk of the Court/Reporter of Decisions, Supreme Court of Idaho, Boise, Idaho, 83720-0101, of any typographical or other formal errors, in order that corrections may be made before the preliminary print goes to press.

### By Release Date

- - *Video Archives are posted if and when available. For best results, use Internet Explorer.

    Release Date | Docket# | Case Name | Opinion Summary Video* | Notes
    Sept 9, 2015 | 42476 | State v. Luis Adame Juarez | - Opinion - Summary | SUBSTITUTE OPINION. The Court's prior Opinion of Sept 1, 2015 is WITHDRAWN.
    August 24, 2015 | 42516 | State v. Andrew Garcia | - Opinion - Summary | Appeal from district court decision to dismiss State's motions for contempt.
    August 24, 2015 | 41982 | State v. Jesse Carl Riendeau | - Opinion - Summary | Appeal from district court order upholding magistrate ruling to admit breath test results.
    August 20, 2015 | 41924 | State v. Felicity Kathleen Haynes | - Opinion - Summary | DUI
    August 20, 2015 | 42823 | State v. Bryann Kristine Lemmons | - Opinion - Summary | Trafficking in methamphetamine
    August 20, 2015 | 41004 | State v. Shannon Marie McKean | - Opinion - Summary | Possession of controlled substance.
    August 7, 2015 | 41494 | State v. Joseph D. Herrera | - Opinion - Summary | Second-degree murder.
    July 21, 2015 | 39249 | State v. Daniel Edward Ehrlick, Jr. | - Opinion - Summary | SUBSTITUTE OPINION. The Court's prior Opinion of April 27, 2015 is WITHDRAWN.
    July 1, 2015 | 42816 | State v. Junior Larry Hilbroom | - Opinion - Summary | No contact order.
    June 23, 2015 | 42671 | State v. Marvin Orellana-Castro | - Opinion - Summary | Lewd conduct, sexual abuse.
    June 22, 2015 | 41736 | State v. Alesha Ann Green | - Opinion - Summary | Motion to suppress.
    May 21, 2015 | 42205 | State v. Kristi L. Hurles | - Opinion - Summary | Grand theft (embezzlement)
    May 4, 2015 | 41644 | State v. Moses Olivas, Jr. | - Opinion - Summary | Sexual abuse of a child and failure to register as a sex offender
    April 8, 2015 | 42486 | State v. Desiree B. Eliasen | - Opinion - Summary | Stalking
    April 1, 2015 | 40301 | State v. Katherine Lea Stanfield | - Opinion - Summary | First Degree Murder
    April 1, 2015 | 42357 | State v. Kenny Carl Struhs | - Opinion - Summary | Vehicular Manslaughter
    Mar 19, 2015 | 41912 | Irwin Ryan Ray Adams v. State | - Opinion - Summary | POST-CONVICTION - Felony vehicular manslaughter.
    Mar 2, 2015 | 31659-39417 | State v. Azad Haji Abdullah | - Opinion - Summary | First-degree murder, arson, felony injury to a child. (Death penalty)
    Feb 27, 2015 | 41811 | State v. Corey Allen Thiel | - Opinion - Summary | State appeals from district court reversal of magistrate decision not to allow early release on good behavior
    Feb 17, 2015 | 41750 | State v. William Franklin Wolfe | - Opinion - Summary | Appeal from denial of motion for reconsideration of Rule 35 motion(s) in fixed life sentence for first-degree murder.
    Feb 09, 2015 | 41174 | State v. Dameniel Preston Owens | - Opinion - Summary | Credit for time served
    Jan 26, 2015 | 40803 | State v. David Aaron Knutsen | - Opinion - Summary | Four counts of sexual abuse of a vulnerable adult.
    Jan 23, 2015 | 42421 | State v. Joseph Anthony Thomas, Jr. | - Opinion - Summary | AMENDED OPINION - First degree murder
    Dec 18, 2014 | 41632 | State v. Derek Michael Arrotta | - Opinion - Summary | Warrantless blood draw
    Dec 9, 2014 | 40619 | State v. Nathan Wade Herren | - Opinion - Summary | SUBSTITUTE OPINION - No contact order and probation violations.
    Dec 2, 2014 | 40603 | State v. Juan Luis Sanchez-Castro | - Opinion - Summary | Trafficking - methamphetamine
    Dec 2, 2014 | 41169 | State v. Dennis John Halseth | - Opinion - Summary | DUI - Motion to suppress results of warrantless blood draw.
    October 30, 2014 | 41477 | State v. Jesse Elias | - Opinion - Summary | Forcible sexual penetration.
    October 29, 2014 | 41645 | State v. Gary L. Schall | - Opinion - Summary | DUI
    October 29, 2014 | 39838 | State v. Jonathan Wade Ellington | - Opinion - Summary | Second degree murder
    October 29, 2014 | 41179 | State v. Micah Abraham Wulff | - Opinion - Summary | DUI - Forced Blood draw
    Sept 19, 2014 | 40553 | State v. Matthew Steven Taylor | - Opinion - Summary | This cross-appeal stems from conspiracy charges re manufacture and delivery of controlled substance.
    Sept 15, 2014 | 41394 | State v. James Leroy Skunkcap | - Opinion - Summary Video | [SUBSTITUTE OPINION - Prior Opinion Withdrawn] Eluding a peace officer; Grand theft.
    Sept 4, 2014 | 40294 | State v. Michael Eugene Koch | - Opinion - Summary | Lewd conduct with a minor under sixteen
    Aug 22, 2014 | 40554 | State v. Charlynda Goggin | - Opinion - Summary Video | Delivery of controlled substance
    Aug 6, 2014 | 38956 | State v. Russell James Parker | - Opinion - Summary | [SUBSTITUTE OPINION - Prior Opinion Withdrawn] Lewd & Lascivious conduct with minor under sixteen
    July 31, 2014 | 41395 | State v. Michael Rowe Russo | - Opinion - Summary Video | Rape, Kidnapping, Burglary
    June 24, 2014 | 40507 | State v. Kyla Alan Richardson | - Opinion - Summary |
    June 19, 2014 | 41275 | State v. Joshua Michael Moses | - Opinion - Summary |
    June 17, 2014 | 41115 | State v. Bob Lester Boren | - Opinion - Summary Video |
    Mar 28, 2014 | 39710/39711 | State v. Krystal Lynn Easley | - Opinion - Summary |
    Mar 28, 2014 | 39877 | State v. Carey Mitchell Baker | - Opinion - Summary |
    Mar 19, 2014 | 40647 | State v. Robert Cassidy Hansen | - Opinion - Summary |
    Mar 19, 2014 | 39400 | Jeffrey Dane Murray v. State | - Opinion - Summary |
    Feb 25, 2014 | 40483 | Alisha Ann Murphy v. State | - Opinion - Summary |
    Feb 21, 2014 | 39567 | State v. Samuel Thomas Glenn | - Opinion - Summary |
    Feb 18, 2014 | 38769 | Sarah M. Johnson v. State | - Opinion - Summary |
    Feb 10, 2014 | 40330 | State v. David Leroy Lee | - Opinion - Summary |
    Dec 2, 2013 | 385228/38704 | Erick Virgil Hall v. State | - Opinion - Summary |
    Nov 27, 2013 | 40586 | Zane Jack Fields v. State | - Opinion - Summary |
    Nov 26, 2013 | 39467-2011 | State v. Todd W. Carver | - Opinion - Summary |
    Nov 26, 2013 | 40076-2012 | State v. Sydney Lorelei Neal | - Opinion - Summary |
    Nov 26, 2013 | 39830-2012 | State v. Matt Eugene Ruck | - Opinion - Summary |
    Nov 13, 2013 | 39550 | State v. Jose Esteban Brunet | - Opinion - Summary |

- Printer-friendly version
- PDF version